@@ -435,6 +435,8 @@ skip_impl = (
     'virDomainGetVcpuPinInfo',
     'virDomainGetEmulatorPinInfo',
     'virDomainPinEmulator',
+    'virDomainGetIOThreadInfo',
+    'virDomainPinIOThread',
     'virSecretGetValue',
     'virSecretSetValue',
     'virSecretGetUUID',
@@ -481,6 +483,7 @@ skip_impl = (
     'virDomainBlockCopy',
     'virNodeAllocPages',
     'virDomainGetFSInfo',
+    'virDomainInterfaceAddresses',
 )
 
 lxc_skip_impl = (
@@ -592,6 +595,8 @@ skip_function = (
     'virNetworkDHCPLeaseFree', # only useful in C, python code uses list
     'virDomainStatsRecordListFree', # only useful in C, python uses dict
     'virDomainFSInfoFree', # only useful in C, python code uses list
+    'virDomainIOThreadInfoFree', # only useful in C, python code uses list
+    'virDomainInterfaceFree', # only useful in C, python code uses list
 )
 
 lxc_skip_function = (
@@ -1144,6 +1149,9 @@ def nameFixup(name, classe, type, file):
     elif name[0:20] == "virDomainGetCPUStats":
         func = name[9:]
         func = func[0:1].lower() + func[1:]
+    elif name[0:24] == "virDomainGetIOThreadInfo":
+        func = name[12:]
+        func = func[0:2].lower() + func[2:]
     elif name[0:18] == "virDomainGetFSInfo":
         func = name[12:]
         func = func[0:2].lower() + func[2:]
